/*
FILE: main.c
DESCRIPTION: Test program demonstrating the usage of the joypad library
WRITTEN BY: Derek Nedelman
DATE: June 19, 2002
HOME PAGE: http://www.playstation2-linux.com/projects/joypadlib 
*/

#include <stdio.h>
#include "joypadlib.h"

void print_stats()
{
	int i;
	int num_joypads;

	num_joypads = joypadlib_num_supported_joypads();

	printf("Total joypads: %d\n", num_joypads);
	
	for (i = 0; i < num_joypads; i++)
	{
		switch (joypadlib_get_joypad_status(i))
		{
			case PS2PAD_STAT_NOTCON: printf("Joystick %d: Not connected\n", i); break;
			case PS2PAD_STAT_READY: printf("Joystick %d: Ready\n", i); break;      
			case PS2PAD_STAT_BUSY: printf("Joystick %d: Busy\n", i); break;
			case PS2PAD_STAT_ERROR: printf("Joystick %d: Error\n", i); break; 		
		}
	}
	printf("\n");

	for (i = 0; i < num_joypads; i++)
	{
		int type;
		switch (type = joypadlib_get_joypad_type(i))
		{
			case PS2PAD_TYPE_NEJICON: printf("Joystick %d: Nejicon\n", i); break;
			case PS2PAD_TYPE_DIGITAL: printf("Joystick %d: Digital\n", i); break;      
			case PS2PAD_TYPE_ANALOG: printf("Joystick %d: Analog\n", i); break;
			case PS2PAD_TYPE_DUALSHOCK: printf("Joystick %d: Dual shock\n", i); break; 		
			default: printf("Joystick %d: %d\n", i, type); break; 		
		}
	}
	printf("\n");

	for (i = 0; i < num_joypads; i++)
	{
		switch (joypadlib_joypad_supports_pressure(i))
		{
			case 0: printf("Joystick %d: Doesn't support pressure sensitivity\n", i); break;
			case 1: printf("Joystick %d: Supports pressure sensitivity\n", i); break;
		}
	}
	printf("\n");
	
	for (i = 0; i < num_joypads; i++)
	{
		int num_actuators = joypadlib_get_joypad_num_actuators(i);
		printf("Joystick %d num actuators: %d\n", i, num_actuators);
	}
	printf("\n");
}

int main(int argc, char** argv)
{
	unsigned long buttons;
	unsigned char button_pressures[PS2PAD_NUM_PRESSURE_BUTTONS];
	float left_stick[2],
              right_stick[2];
	int active_joypad = 0;
	
	joypadlib_initialize();

	print_stats();	
	
	puts("Press anything on the joypad to see something happen.");
	puts("Press the CROSS button to turn on the varying actuator. The harder you press, the harder it vibrates.");
	puts("Press the SQUARE button to turn on the constant actuator.");
	puts("Press the TRIANGLE button to stop the vibrations.");
	puts("Press the START button to exit.");
	
	for (;;) 
	{
		joypadlib_update();		
		
		buttons = joypadlib_get_joypad_buttons(active_joypad, button_pressures, PRESSURE_TYPE_BYTE);
		joypadlib_get_joypad_sticks(active_joypad, left_stick, right_stick);

		if (buttons & PS2PAD_BUTTON_LEFT) 
		{
			printf("Pressed left. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_DIGITAL_LEFT]);
		}		
		if (buttons & PS2PAD_BUTTON_UP)
		{
			printf("Pressed up. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_DIGITAL_UP]);
		}		
		if (buttons & PS2PAD_BUTTON_RIGHT) 
		{
			printf("Pressed right. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_DIGITAL_RIGHT]);
		}		
		if (buttons & PS2PAD_BUTTON_DOWN) 
		{
			printf("Pressed down. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_DIGITAL_DOWN]);
		}
		
		if (buttons & PS2PAD_BUTTON_L1) 
		{
			printf("Pressed L1. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_L1]);
		}		
		if (buttons & PS2PAD_BUTTON_L2) 
		{
			printf("Pressed L2. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_L2]);
		}
		if (buttons & PS2PAD_BUTTON_L3) 
		{
			puts("Pressed L3");
		}
		
		if (buttons & PS2PAD_BUTTON_R1) 
		{
			printf("Pressed R1. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_R1]);
		}		
		if (buttons & PS2PAD_BUTTON_R2) 
		{
			printf("Pressed R2. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_R2]);
		}
		if (buttons & PS2PAD_BUTTON_R3) 
		{
			puts("Pressed R3");
		}
		
		if (buttons & PS2PAD_BUTTON_START) 
		{
			puts("Pressed start");
			break;
		}		
		if (buttons & PS2PAD_BUTTON_SELECT) 
		{
			puts("Pressed select");
		}
		
		if (buttons & PS2PAD_BUTTON_TRIANGLE) 
		{
			printf("Pressed triangle. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_TRIANGLE]);
		}		
		if (buttons & PS2PAD_BUTTON_CIRCLE) 
		{			
			printf("Pressed circle. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_CIRCLE]);
		}		
		if (buttons & PS2PAD_BUTTON_SQUARE) 
		{
			printf("Pressed square. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_SQUARE]);
		} 
		if (buttons & PS2PAD_BUTTON_CROSS) 
		{
			printf("Pressed cross. Pressure: %d\n", button_pressures[PS2PAD_PRESSURE_CROSS]);			
		}	

		if ((left_stick[0] != 0.0f) || (left_stick[1] != 0.0f))
		{
			printf("Left stick x/y: %f %f\n", left_stick[0], left_stick[1]);
		}

		if ((right_stick[0] != 0.0f) || (right_stick[1] != 0.0f))
		{
			printf("Right stick x/y: %f %f\n", right_stick[0], right_stick[1]);
		}

		//Take care of rumble
		if ((buttons & PS2PAD_BUTTON_SQUARE) && (buttons & PS2PAD_BUTTON_CROSS)) 
		{
			//Activate both actuators

			joypadlib_set_joypad_actuators(active_joypad, 1, button_pressures[PS2PAD_PRESSURE_CROSS]);
		} 
		else if (buttons & PS2PAD_BUTTON_CROSS) 
		{
			//Activate the analog actuator

			joypadlib_set_joypad_actuators(active_joypad, 0, button_pressures[PS2PAD_PRESSURE_CROSS]);
		} 
		else if (buttons & PS2PAD_BUTTON_SQUARE) 
		{
			//Activate the small/const actuator

			joypadlib_set_joypad_actuators(active_joypad, 1, 0);
		} 

		if (buttons & PS2PAD_BUTTON_TRIANGLE) 
		{
			//Shut off the rumble on both actuators

			joypadlib_set_joypad_actuators(active_joypad, 0, 0);
		} 
	}
	
	joypadlib_shutdown();
	return 0;
}
